@@ -1,12 +1,8 @@
-"""
-
-"""
-
-import logging
-
 from django.db import models
 
-log = logging.getLogger(__name__)
+__all__ = [
+    "MentionsBaseModel",
+]
 
 
 class MentionsBaseModel(models.Model):
